# Copyright 2013-2020 Lawrence Livermore National Security, LLC and other
# Spack Project Developers. See the top-level COPYRIGHT file for details.
#
# SPDX-License-Identifier: (Apache-2.0 OR MIT)

from spack import *


class PyPygeos(PythonPackage):
    """PyGEOS is a C/Python library with vectorized geometry functions.

    The geometry operations are done in the open-source geometry library GEOS.
    PyGEOS wraps these operations in NumPy ufuncs providing a performance
    improvement when operating on arrays of geometries."""

    homepage = "https://github.com/pygeos/pygeos"
    url      = "https://pypi.io/packages/source/p/pygeos/pygeos-0.8.tar.gz"

    maintainers = ['adamjstewart']

    version('0.8', sha256='45b7e1aaa5fc9ff53565ef089fb75c53c419ace8cee18385ec1d7c1515c17cbc')

    depends_on('python@3:', type=('build', 'link', 'run'))
    depends_on('py-setuptools', type='build')
    depends_on('py-numpy@1.10:', type=('build', 'link', 'run'))
    depends_on('geos@3.5:')
